"""
Replace all occurences of <scriptName> with your chosen script name
Copy and paste code into notepad and save as <scriptName>.py (* All file giveTypes)
Upload file to .../addons/eventcripts/<scriptName>/
Add the following line to your autoexec.cfg:
es_load <scriptName>
Restart your server
Requires EventScripts v2.0.0.250i -> http://Mattie.info/Cs
"""

''' Eventscript Imports '''
import es
import cfglib
import cmdlib
import playerlib
import popuplib
import services

''' Addon Information '''
info = es.AddonInfo()
info.name = "Extensive Give"
info.version = "1.0"
info.basename = (__name__.split(".", 1)[~0].replace(".", "/"))
info.author = "aDz"
info.description = "EventScripts v2.0.0.250i Addon: Extensive Give"

''' Configuration '''
cfg = cfglib.AddonCFG(es.getAddonPath(info.basename) + "/%s.cfg" % info.basename)
cfg.text("%s [v%s] Configuration" %(info.name, info.version))
cfg.text("")
cfg.text("General Settings")
adminOnly = cfg.cvar("%s_adminOnly" % info.basename, 1, "Admin Only (Boolean) [Default=1]")
giveCommand = cfg.cvar("%s_giveCommand" % info.basename, "@give", "Give Command (String) [Default=\"@give\"]")
announceGive = cfg.cvar("%s_announceGive" % info.basename, 1, "Announce Message (Boolean) [Default=1]")
syntaxMessage = cfg.cvar("%s_syntaxMessage" % info.basename, "Syntax = <giveCommand> <playerFilters/targetName/targetSteamid/targetUserid> <type> <value>", "Syntax Message (String) [Default=\"Syntax = <giveCommand> <playerFilters/targetName/targetSteamid/targetUserid> <type> <value>\"]")
cfg.text("")
cfg.write()

''' Data Structures '''
valueDict = {}
entityDict = {
    "Item": {
        "Kevlar": "Kevlar",
        "Assaultsuit": "Kevlar & Helmet",
        "Defuser": "Defusal Kit",
        "Nvgs": "Nightvision"},
    "Weapon": {
        "Glock": "9x19mm Sidearm",
        "Usp": "Universal Self-Loading Pistol",
        "P228": "228 Compact",
        "Deagle": "Night Hawk .50c", 
        "Fiveseven": "ES Five-Seven",
        "Elite": "5.40 Dual Elites",
        "M3": "Leone 12 Gauge Super",
        "Xm1014": "Leone YG1265 Auto Shotgun",
        "Mac10": "Ingram Mac-10",
        "Tmp": "Schmidt Machine Pistol",
        "Mp5navy": "MP5 Navy",
        "Ump45": "KM UMP45",
        "P90": "ES C90",
        "Defender": "IDF Defender",
        "Famas": "Clarion",
        "Ak47": "CV-47",
        "M4a1": "Maverick M4A1 Carbine",
        "Scout": "Schmidt Scout",
        "Sg552": "Krieg 552",
        "Aug": "Bullpup",
        "G3sg1": "D3/AU-1",
        "Sg550": "Krieg 550 Commando",
        "Awp": "Magnum Sniper Rifle",
        "M249": "M249 Para",
        "Flashbang": "Flash Bang",
        "Hegrenade": "HE Grenade",
        "Smokegrenade": "Smoke Grenade"}}
popupDict = {}

''' Wrapping Functions '''
def msg(text):
    es.msg("#multi", "#lightgreen%s #green[v%s] #default:: %s" %(info.name, info.version, text))

def tell(userid, text):
    es.tell(userid, "#green", text)

''' Necessary Functions '''
def load():
    msg("Loaded.")
    cfg.execute()
    cmdlib.registerClientCommand(giveCommand, giveCmd, "Client Console Command: %s" % giveCommand)
    cmdlib.registerSayCommand(giveCommand, giveCmd, "Client Say Command: %s" % giveCommand)
    es.addons.registerSayFilter(sayFilter)
    playerlib.registerPlayerListFilter("admin", adminFilter)

def unload():
    msg("Unloaded.")
    cmdlib.unregisterClientCommand(giveCommand)
    cmdlib.unregisterSayCommand(giveCommand)
    es.addons.unregisterSayFilter(sayFilter)
    playerlib.unregisterPlayerListFilter("admin")
    for x in popupDict:
        popuplib.delete(x[5:])
    
''' Authorization Services '''
def setupAuth():
    global isAuthed
    if services.isRegistered("auth"):
        auth_service = services.use("auth")
        auth_service.registerCapability("extensiveGive", auth_service.ADMIN)
        isAuthed = lambda x: auth_service.isUseridAuthorized(x, "extensiveGive")
    else:
        isAuthed = lambda x: False
        
setupAuth()
    
''' Registered Commands '''
def giveCmd(userid, args):
    if adminOnly and not isAuthed(userid):
        return tell(userid, "You do not have the required permissions to use this command.")
    if args:
        if len(args) > 2:
            if es.getuserid(args[0]) or args[0].startswith("#"):
                args[1] = args[1].capitalize()
                if args[1] in ("Cash", "Health", "Item", "Weapon"):
                    integerTypes = ("Cash", "Health")
                    if args[1] in integerTypes and args[2].isdigit() or args[1] in ("Item", "Weapon") and args[2] in entityDict[args[1]]:
                        if args[0].startswith("#"):
                            for x in playerlib.getUseridList(args[0]):
                                giveWeapon(userid, x, args[1], args[2])
                            return
                        return giveWeapon(userid, es.getuserid(args[0]), args[1], args[2])
                    return tell(userid, "Invalid Value. Value = %s" % ("Integer Amount" if args[1] in integerTypes else "item_<itemCode>/weapon_<weaponCode>"))
                return tell(userid, "Invalid Type. Type = Cash/Health/Item/Weapon")
            return tell(userid, "Invalid Target. Target = <playerFilters/targetName/targetSteamid/targetUserid>")
        return tell(userid, "Invalid Arguments. %s" % syntaxMessage)
    tell(userid, syntaxMessage)
    sendPopup(userid)
    
''' Custom Functions '''
def adminFilter(x):
    return bool(isAuthed(x))
    
def giveWeapon(userid, target, giveType, value):
    giveType = str.lower(giveType)
    if str.capitalize(giveType) in ("Cash", "Health"):
        player = playerlib.getPlayer(target)
        player.set(giveType, player.get(giveType) + int(value))
        if announceGive:
            msg("%s gave player %s %s %s" %(es.getplayername(userid), es.getplayername(target), value, giveType))
    else:
        es.server.queuecmd("es_xgive %s %s_%s" %(target, giveType, value))
        if announceGive:
            msg("%s gave player %s %s_%s" %(es.getplayername(userid), es.getplayername(target), giveType, value))
    
def intTeam(team):
    if team != "#all":
        return (2) if  team == "#t" else (3)
    return (2, 3)
    
def sendPopup(userid):
    popupDict["popupTarget"] = popuplib.easymenu("popupTargets", None, popupTarget_Select)
    popupDict["popupTarget"].settitle("%s [v%s]" %(info.name, info.version))
    popupDict["popupTarget"].setdescription(":: Target")
    for x in filter(lambda x: es.getplayerteam(x) > 1, es.getUseridList()):
        popupDict["popupTarget"].addoption(x, es.getplayername(x))
    popupDict["popupTarget"].send(userid)
    
''' Event Functions '''
def player_disconnect(event_var):
    userid = int(event_var["userid"])
    if userid in valueDict:
        del valueDict[userid]
        
''' Popup Menuselects '''
def popupEntity_Select(userid, choice, popupName):
    giveWeapon(userid, choice[0], choice[1], choice[2])
    popupType_Select(userid, (choice[0], choice[1]), None)
    
def popupTarget_Select(userid, choice, popupName):
    popupDict["popupType"] = popuplib.easymenu("popupType", None, popupType_Select)
    popupDict["popupType"].settitle("%s [v%s]" %(info.name, info.version))
    popupDict["popupType"].setdescription(":: Type")
    for x in ("Cash", "Health", "Item", "Weapon"):
        popupDict["popupType"].addoption((choice, x), x)
    popupDict["popupType"].send(userid)
    
def popupType_Select(userid, choice, popupName):
    if choice[1] in ("Cash", "Health"):
        valueDict[userid] = (choice[0], choice[1])
        return tell(userid, "Please input a valid integer value.")
    popupDict["popup%s" % choice[1]] = popuplib.easymenu("popup%s" % choice[1], None, popupEntity_Select)
    popupDict["popup%s" % choice[1]].settitle("%s [v%s]" %(info.name, info.version))
    popupDict["popup%s" % choice[1]].setdescription(":: Entity Code")
    for x in entityDict[choice[1]]:
        popupDict["popup%s" % choice[1]].addoption((choice[0], choice[1], x), "%s (%s)" %(x, entityDict[choice[1]][x]))
    popupDict["popup%s" % choice[1]].send(userid)
        
''' Registered Filters '''
def sayFilter(userid, text, teamonly):
    text = text.strip('"')
    if userid in valueDict:
        if text.isdigit():
            giveWeapon(userid, valueDict[userid][0], valueDict[userid][1], text)
            del valueDict[userid]
            return (None, None, None)
        tell(userid, "Invalid Value. Value = Integer Amount")
        return (None, None, None)
    return (userid, text, teamonly)